// Generated on <%= (new Date).toISOString().split('T')[0] %> using
// <%= pkg.name %> <%= pkg.version %>
'use strict';

// # Globbing
// for performance reasons we're only matching one level down:
// 'test/spec/{,*/}*.js'
// If you want to recursively match all subfolders, use:
// 'test/spec/**/*.js'

module.exports = function (grunt) {

  // Time how long tasks take. Can help when optimizing build times
  require('time-grunt')(grunt);

  // Load grunt tasks automatically
  require('load-grunt-tasks')(grunt);

  // Configurable paths
  var config = {
    serverPort: 8000,
    optimsationLevel: 3
  };

  // Define the configuration for all the tasks
  grunt.initConfig({

    // Project settings
    config: config,

    // Watches files for changes and runs tasks based on the changed files
    watch: {
      bower: {
        files: ['bower.json'],
        tasks: ['wiredep', 'bower_concat']
      },
      images: {
        files: ['images/{,*/}*.{gif,jpeg,jpg,png,svg}'],
        tasks: ['newer:imagemin', 'newer:svgmin']
      },
      scripts: {
        files: ['js/{,*/}*.js'],
        tasks: ['jshint']
      },
      gruntfile: {
        files: ['Gruntfile.js']
      },
      sass: {
        files: ['styles/{,*/}*.{scss,sass}'],
        tasks: ['sass', 'autoprefixer', 'newer:imagemin', 'newer:svgmin']
      },
      php: {
        files: ['**/*.php']
      },
      options: {
        livereload: true
      }
    },

    // The actual grunt server settings
    php: {
      server: {
        options: {
          port: '<%= config.serverPort %>',
          keepalive: true,
          open: false,
          base: '../../../'
        }
      }
    },

    // Empties folders to start fresh
    clean: {
      build: {
        files: [{
          dot: true,
          src: [
            'css',
            'img',
            '.sass-cache',
            '!.git*'
          ]
        }]
      },
      vendors: {
        files: [{
          dot: true,
          src: [
            'bower_components',
            '!.git*'
          ]
        }]
      }
    },

    // Make sure code styles are up to par and there are no obvious mistakes
    jshint: {
      options: {
        jshintrc: '.jshintrc',
        reporter: require('jshint-stylish')
      },
      all: [
        '!Gruntfile.js',
        'js/{,*/}*.js',
        '!js/vendor.js',
        '!js/modernizr.js'
      ]
    },

    // Compiles Sass to CSS and generates necessary files if requested
    sass: {
      options: {
        loadPath: 'bower_components',
        require: 'susy'
      },
      all: {
        files: [{
          expand: true,
          cwd: 'styles',
          src: ['*.{scss,sass}'],
          dest: 'css',
          ext: '.css',
          style: 'expanded'
        }]
      }
    },

    // Add vendor prefixed styles
    autoprefixer: {
      options: {
        browsers: ['> 1%', 'last 2 versions', 'Firefox ESR', 'Opera 12.1']
      },
      all: {
        files: [{
          expand: true,
          cwd: 'css/',
          src: '{,*/}*.css',
          dest: 'css/'
        }]
      }
    },

    // Automatically inject Bower components into the Sass file
    wiredep: {
      sass: {
        src: ['styles/{,*/}*.{scss,sass}']
      }
    },

    // Concatenate all bower dependencies
    bower_concat: {
      all: {
        dest: 'js/vendor.js',
        cssDest: 'styles/vendor.scss',
        exclude: [
          'jquery',
          'modernizr'
        ],
        bowerOptions: {
          relative: false
        }
      }
    },

    // Run any command line task
    shell: {
      options: {
        stderr: false
      },
      bower: {
        command: 'bower install'
      },
      npm: {
        command: 'npm install'
      },
      vagrant: {
        command: [
          'cd ../../../',
          'vagrant up',
          'cd -'
        ].join('&&')
      }
    },

    // The following *-min tasks produce minified files in the prod folder
    imagemin: {
      options: {
        optimizationLevel: '<%= config.optimsationLevel %>'
      },
      all: {
        files: [{
          expand: true,
          cwd: 'images',
          src: '{,*/}*.{gif,jpeg,jpg,png}',
          dest: 'img'
        }]
      }
    },

    svgmin: {
      all: {
        files: [{
          expand: true,
          cwd: 'images',
          src: '{,*/}*.svg',
          dest: 'img'
        }]
      }
    },

    // Generates a custom Modernizr build that includes only the tests you
    // reference in your app
    modernizr: {
      build: {
        devFile: 'bower_components/modernizr/modernizr.js',
        outputFile: 'js/modernizr.js',
        files: {
          src: [
            'js/{,*/}*.js',
            'css/{,*/}*.css',
            '!js/vendor/*'
          ]
        },
        uglify: true
      }
    },

    // Run some tasks in parallel to speed up build process
    concurrent: {
      styles: [
        'sass',
        'autoprefixer',
        'imagemin',
        'svgmin'
      ],
      scripts: [
        'jshint',
        'modernizr'
      ]
    },

    // Generate all instances of Favicons known to man!!!
    favicons: {
      options: {
        trueColor: true,
        precomposed: true,
        appleTouchBackgroundColor: '#FFFFFF',
        coast: true,
        windowsTile: true,
        tileBlackWhite: false,
        tileColor: 'auto'
      },
      icon: {
        src: 'images/favicons/favicon.png',
        dest: 'img/favicons'
      }
    }
  });

  grunt.registerTask('update', [
    'clean:build',
    'clean:vendors',
    'shell:npm',
    'shell:bower',
    'wiredep',
    'bower_concat'
  ]);

  grunt.registerTask('run', function () {
    grunt.task.run([
      'clean:build',
      'wiredep',
      'bower_concat',
      'concurrent',
      'watch'
    ]);
  });

  grunt.registerTask('vagrant', [
    'shell:vagrant',
    'run'
  ]);

  grunt.registerTask('build', [
    'clean:build',
    'wiredep',
    'bower_concat',
    'concurrent',
    'favicons'
  ]);

  grunt.registerTask('default', [
    'run'
  ]);
};
