<?php

/**
 * Includes
 */
include_once dirname(__FILE__) . '/includes/theme.inc';
include_once dirname(__FILE__) . '/includes/menu.inc';
include_once dirname(__FILE__) . '/includes/form.inc';
include_once dirname(__FILE__) . '/includes/views.inc';

/**
 * Implements template_preprocess_html()
 */
function <%= projectSlug %>_preprocess_html(&$variables) {
	$viewport = array(
	  '#tag' => 'meta',
	  '#attributes' => array(
	    'name' => 'viewport',
	    'content' => 'width=device-width, initial-scale=1',
	  ),
	);
	drupal_add_html_head($viewport, 'viewport');
}

/**
 * Implements template_preprocess_page()
 */
function <%= projectSlug %>_preprocess_page(&$variables) {
  // Page template suggestions
  if (isset($variables['node']->type)) {
    $variables['theme_hook_suggestions'][] = 'page__type_' . $variables['node']->type;
	}

	// Add the front page suggestion at the top of the pile as it may have been overriden above
  if (drupal_is_front_page()) {
    $variables['theme_hook_suggestions'][] = 'page__front';
  }
}

/**
 * Implements template_preprocess_node()
 */
function <%= projectSlug %>_preprocess_node(&$variables) {
  if (isset($variables['node']->type) && isset($variables['view_mode'])) {
		// Node template suggestions based on view mode
		// Additional view modes are added by hook_entity_info_alter() in a custom module
    $variables['theme_hook_suggestions'][] = 'node__mode_' . $variables['view_mode'];
    $variables['theme_hook_suggestions'][] = 'node__' . $variables['node']->type . '__mode_' . $variables['view_mode'];

    // Add an extra class to the node wrapper with the view mode
    if (isset($variables['view_mode'])) {
      $variables['classes_array'][] = 'mode-' . $variables['view_mode'];
    }
  }

	// Remove unnecessary 'node-teaser' class
	if (($key = array_search('node-teaser', $variables['classes_array'])) !== false) {
	  unset($variables['classes_array'][$key]);
	}

  // Override the 'Submitted by' string
	// See the Drupal time formats UI for changing the date formatting
	$variables['submitted'] = t('By !username. Posted on !datetime', array('!username' => $variables['name'], '!datetime' => $variables['date']));
}

/**
 * Implements template_preprocess_field()
 */
function <%= projectSlug %>_preprocess_field(&$variables, $hook) {

}

/**
 * Preprocess variables for region.tpl.php.
 *
 * @see region.tpl.php
 */
function <%= projectSlug %>_preprocess_region(&$variables, $hook) {

	// Region template adds an additional wrapper div. Certain regions can opt
	// to use a different template with no extra wrapper div.
  switch ($variables['region']) {
    case 'content':
    case 'highlighted':
    case 'navigation':
		case 'sidebar_first':
		case 'sidebar_second':
      $variables['theme_hook_suggestions'][] = 'region__no_wrapper';
      break;
  }
}

/**
 * Preprocess variables for block.tpl.php.
 *
 * @see block.tpl.php
 */
function <%= projectSlug %>_preprocess_block(&$variables, $hook) {
	// Add an additional class to the block title
  $variables['title_attributes_array']['class'][] = 'block-title';

	// Block template adds an additional wrapper div. Certain block IDs can opt
	// to use a different template with no extra wrapper div.
  switch ($variables['block_html_id']) {
    case 'block-system-main':
      $variables['theme_hook_suggestions'][] = 'block__no_wrapper';
      break;
  }

	// Block template adds an additional wrapper div. Blocks in certain regions
	// can opt to use a different template with no extra wrapper div.
  switch ($variables['block']->region) {
    case 'highlighted':
      $variables['theme_hook_suggestions'][] = 'block__no_wrapper';
      break;
  }
}

/**
 * Implements template_preprocess_username().
 */
function <%= projectSlug %>_preprocess_username(&$variables) {
	// By default Drupal adds '(not verified)' to the username for anonymous users
	// (like in comments). I can't see why we need to see this. You can turn this
	// off somewhere deep in the GUI but blanking the text here also works ;)
  $variables['extra'] = '';
}

/**
 * Implements hook_theme()
 */
function <%= projectSlug %>_theme(&$existing, $type, $theme, $path) {
	// Our custom theme hooks wont work unless we declare them here.
  $hook_theme = array(
    'search_form_wrapper' => array(
      'render element' => 'element',
    )
  );

  return $hook_theme;
}

/**
 * Provide a function to build the HTML for social sharing buttons
 *
 * $url : The full url of the content to be shared (this will be shortened). Defaults to the current request path.
 * $title : The title or caption to use on the social network. Defaults to the Drupal page title.
 * $media : A url to an image to support this social post (Pinterest only)
 * $label : Boolean. Sets if the buttons include the 'Share' label.
 * $handle : Optionally supply an @twitteruser handle to be appended to the suggested tweet text.
 */
function social_share_buttons($url = NULL, $title = NULL, $media = '', $label = FALSE, $handle = NULL) {

  if (!$url) {
    $url = "http://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
  }
  if (!$title) {
    $title = drupal_get_title();
  }
  if ($handle) {
    $title_twitter = $title . ' via ' . $handle;
    $title .= ' | SITE NAME';
  }
  else {
    $title .= ' | SITE NAME';
    $title_twitter = $title;
  }

  // If the Shurly url shortener is available we'll shrink the URL
  if (module_exists('shurly')) {
		// Force shurly to only create one shortcode (using the anonymous uid)
		$account = new stdClass;
		$account->uid = '0';
		$account->roles = array(1 => 'annonymous user');
    $shorturl = shurly_shorten($url, NULL, $account);

    if (!empty($shorturl['shortUrl'])) {
      $url = $shorturl['shortUrl'];
    }
  }
  // We can also remove the http:// and www. for space saving
  $url = str_replace(array('http://', 'www.'), '', $url);

  $facebook = 'https://www.facebook.com/sharer/sharer.php?u=' . urlencode($url);
  $twitter = 'https://twitter.com/home?status=' . urlencode($title_twitter . ' | ' . $url);
  $google = 'https://plus.google.com/share?url=' . urlencode($url);
  $pinterest = 'https://pinterest.com/pin/create/button/?url=' . urlencode($url) . '&media=' . urlencode($media) . '&description=' . urlencode($title);
  $linkedin = 'https://www.linkedin.com/shareArticle?mini=true&url=' . urlencode($url) . '&title=' . urlencode($title) . '&summary=&source=';

  return '<ul class="social-sharing">' .
  (($label) ? '<li class="label"><span>' . t('Share') . '</span><i class="flaticon flaticon-share"></i></li>' : '') .
  '<li><a href="' . $facebook . '" title="' . t('Share on Facebook') . '" class="link-popup-window share-facebook"><i class="flaticon-facebook"></i></a></li>' .
  '<li><a href="' . $twitter . '" title="' . t('Share on Twitter') . '" class="link-popup-window share-twitter"><i class="flaticon-twitter"></i></a></li>' .
  '<li><a href="' . $google . '" title="' . t('Share on Google+') . '" class="link-popup-window share-googleplus"><i class="flaticon-google"></i></a></li>' .
  '<li><a href="' . $linkedin . '" title="' . t('Share on LinkedIn') . '" class="link-popup-window share-linkedin"><i class="flaticon-linkedin"></i></a></li>' .
  '<li><a href="' . $pinterest . '" title="' . t('Share on Pinterest') . '" data-pin-do="skipLink" class="link-popup-window share-pinterest"><i class="flaticon-pinterest"></i></a></li>' .
  '</ul>';
}

/**
 * Useful function to get the exposed filter form of a view
 */
function views_exposed_filter_form($view_name, $display_id) {
  // Embed the press release filters
  $view = views_get_view($view_name);
  $view->set_display($display_id);
  $view->init_handlers();
  $form_state = array(
    'view' => $view,
    'display' => $view->display_handler->display,
    'exposed_form_plugin' => $view->display_handler->get_plugin('exposed_form'),
    'method' => 'get',
    'rerender' => TRUE,
    'no_redirect' => TRUE,
  );
  $form = drupal_build_form('views_exposed_form', $form_state);

  if ($form) {
    return $form;
  }
  return FALSE;
}

/**
 * When given a checkbox field this will return TRUE for 1 and FALSE for 0.
 *
 * @param $field The field array.
 * @return bool A translation of the field array into boolean.
 */
function check_boolean($field) {
  if (isset($field) && !empty($field)) {
    if ($field['und'][0]['value'] == '1') {
      return TRUE;
    }
    else {
      return FALSE;
    }
  }
  else {
    return FALSE;
  }
}
